#library imports
library(dplyr) #import deployer for table manipulation
library(psych) #import psych for cranbach's alpha
library(readxl) #import readxl to import xslx files

# -----------------------------------------
# Data analysis
# To analyse if there is a significant difference between the two conditions
# -----------------------------------------

#import data
Data_total_for_analysis_cleaned_Final <- read_excel("Value_Elicitation_-_anonymized_dataset.xlsx")

# Variables used in data analysis to reduce duplicated code
condition_list <- Data_total_for_analysis_cleaned_Final$Condition
q1_19_mean_list <- Data_total_for_analysis_cleaned_Final$'Q1-19_Mean'
q20_23_mean_list <- Data_total_for_analysis_cleaned_Final$'Q20-23_Mean'
q24 <- Data_total_for_analysis_cleaned_Final$'Q24-Numeric'

# Calculate Cronbach's alpha to show internal consistancy between Q20-Q23
c_alpha <- alpha(Data_total_for_analysis_cleaned_Final %>% select('Q20-Numeric', 'Q21-Numeric', 'Q22-Numeric', 'Q23-Numeric'))
c_alpha# Value is 0.83 which indicated there is internal cohesion


# Calculation to check if the data is normally distributed
value_normal_distr <- shapiro.test(q1_19_mean_list)
difficulty_normal_distr <- shapiro.test(q20_23_mean_list)
q24_normal_distr <- shapiro.test(q24)

# Check the results of the shapiro.test for the 3 type of questions
value_normal_distr# p-value = 2.61e-13 indicating it is not normally distibuted
difficulty_normal_distr# p-value = 0.0001388 indicating it is not normally distibuted
q24_normal_distr# p-value = 1.247e-12 indicating it is not normally distibuted

# Perform the wilcox test to check significant change in conditions
value_test <- wilcox.test(q1_19_mean_list ~ condition_list)
difficulty_test <- wilcox.test(q20_23_mean_list ~ condition_list)
q24_test <- wilcox.test(q24 ~ condition_list)

value_test# p-value = 0.0003821 indicating a significant difference between conditions' time taking the survey 
difficulty_test# p-value = 0.0001169 indicating a significant difference between conditions' answers regarding the difficulty of the survey
q24_test# p-value = 0.4547 indicating NO significant difference between conditions' regarding lack of answers